Learn R Programming

phenoDist (version 1.20.0)

ctlSeparatn: Calculate control separation

Description

This function calculates the Z'-factor between negative and positive controls, based on phenotypic distance measurements.

Usage

ctlSeparatn(x, pheno, neg='rluc', pos='ubc', ...)

Arguments

x
An imageHTS object.
pheno
A numeric vector for distances to negative controls, as returned from distToNeg.
neg
A character string to identify negative controls.
pos
A character string to identify positive controls.
...
Additional arguments to be passed to the Zprime function of the imageHTS package.

Value

The Z'-factor value.

Details

Phenotypes of negative and positive controls are defined as their phenotypic distance to negative controls. The Z'-factor is a metric measuring the separation between negative controls and positive controls (Zhang et al. 1999). This function calls the Zprime function of the imageHTS package to calculate the Z'-factor. Please see Zprime for detailed description of the definition and calculation of the Z'-factor.

References

J. H. Zhang, T. D. Chung, K. R. Oldenburg. A Simple Statistical Parameter for Use in Evaluation and Validation of High Throughput Screening Assays. J Biomol Screening, 1999.

See Also

distToNeg, Zprime

Examples

Run this code

## see distToNeg.

Run the code above in your browser using DataLab